+++
title = "Piezoelectric Actuators"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Actuators]({{< relref "actuators" >}})


## Piezoelectric Stack Actuators {#piezoelectric-stack-actuators}


### Manufacturers {#manufacturers}

| Manufacturers       | Links                                                                              |
|---------------------|------------------------------------------------------------------------------------|
| Cedrat              | [link](http://www.cedrat-technologies.com/)                                        |
| PI                  | [link](https://www.physikinstrumente.com/en/)                                      |
| Piezo System        | [link](https://www.piezosystem.com/products/piezo%5Factuators/stacktypeactuators/) |
| Noliac              | [link](http://www.noliac.com/)                                                     |
| Thorlabs            | [link](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup%5Fid=8700)           |
| PiezoDrive          | [link](https://www.piezodrive.com/actuators/)                                      |
| Mechano Transformer | [link](http://www.mechano-transformer.com/en/products/10.html)                     |
| CoreMorrow          | [link](http://www.coremorrow.com/en/pro-9-1.html)                                  |


### Model {#model}

A model of a multi-layer monolithic piezoelectric stack actuator is described in <sup id="c823f68dd2a72b9667a61b3c046b4731"><a class="reference-link" href="#fleming10_nanop_system_with_force_feedb" title="Fleming, Nanopositioning System With Force Feedback for  High-Performance Tracking and Vibration Control, {IEEE/ASME Transactions on Mechatronics}, v(3), 433-447 (2010).">(Fleming, 2010)</a></sup> ([Notes]({{< relref "fleming10_nanop_system_with_force_feedb" >}})).


### Specifications {#specifications}

Typical specifications of piezoelectric stack actuators are usually in terms of:

-   Displacement/ Travel range \\([\mu m]\\)
-   Blocked force \\([N]\\)
-   Stiffness \\([N/\mu m]\\)
-   Resolution \\([nm]\\)
-   Length \\([mm]\\)


#### Displacement and Length {#displacement-and-length}

The maximum displacement specified is the displacement of the actuator when the maximum voltage is applied and when no load is added.

Typical strain of Piezoelectric Stack Actuators is \\(0.1\%\\), the free displacement \\(d\\) is then related to the length of piezoelectric stack:
\\[ d \approx \frac{L}{1000} \\]


#### Blocked Force {#blocked-force}

The blocked force is measured by first applying the maximum voltage to the piezoelectric stack without any load.
Thus, the piezoelectric stack experiences its maximum displacement.

A force is then applied to return the actuator to its original length.
This force is measured and recorded as the blocking force.

The blocking force is also the maximum force that can produce the piezoelectric stack in contact with an infinitely stiff environment.


#### Stiffness {#stiffness}


#### Resolution {#resolution}

The resolution is limited by the noise in the voltage amplified.

Typical [Signal to Noise Ratio]({{< relref "signal_to_noise_ratio" >}}) of voltage amplified is \\(100dB = 10^{5}\\).
Thus, for a piezoelectric stack with a displacement \\(L\\), the resolution will be

\begin{equation}
  r = \frac{L}{10^5}
\end{equation}

For a piezoelectric stack with a displacement of \\(100\,[\mu m]\\), the resolution will be \\(\approx 1\,[nm]\\).


### Piezoelectric Stack experiencing a mass load {#piezoelectric-stack-experiencing-a-mass-load}


### Piezoelectric Stack in contact with a spring load {#piezoelectric-stack-in-contact-with-a-spring-load}


## Mechanically Amplified Piezoelectric actuators {#mechanically-amplified-piezoelectric-actuators}

The Amplified Piezo Actuators principle is presented in <sup id="5decd2b31c4a9842b80c58b56f96590a"><a class="reference-link" href="#claeyssen07_amplif_piezoel_actuat" title="Frank Claeyssen, Le Letty, Barillot, \&amp; Sosnicki, Amplified Piezoelectric Actuators: Static \&amp; Dynamic  Applications, {Ferroelectrics}, v(1), 3-14 (2007).">(Frank Claeyssen {\it et al.}, 2007)</a></sup>:

> The displacement amplification effect is related in a first approximation to the ratio of the shell long axis length to the short axis height.
> The flatter is the actuator, the higher is the amplification.

A model of an amplified piezoelectric actuator is described in <sup id="849750850d9986ed326e74bd3c448d03"><a class="reference-link" href="#lucinskis16_dynam_charac" title="@misc{lucinskis16_dynam_charac,
  author          = {R. Lucinskis and C. Mangeot},
  title           = {Dynamic Characterization of an amplified piezoelectric
                  actuator},
  year            = 2016,
}">(Lucinskis \& Mangeot, 2016)</a></sup>.

| Manufacturers       | Links                                                                                                                                                                                                                                             |
|---------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Cedrat              | [link](https://www.cedrat-technologies.com/en/products/actuators/amplified-piezo-actuators.html)                                                                                                                                                  |
| PiezoDrive          | [link](https://www.piezodrive.com/actuators/ap-series-amplified-piezoelectric-actuators/)                                                                                                                                                         |
| Dynamic-Structures  | [link](https://www.dynamic-structures.com/category/piezo-actuators-stages)                                                                                                                                                                        |
| Thorlabs            | [link](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup%5Fid=8700)                                                                                                                                                                          |
| Noliac              | [link](http://www.noliac.com/products/actuators/amplified-actuators/)                                                                                                                                                                             |
| Mechano Transformer | [link](http://www.mechano-transformer.com/en/products/01a%5Factuator%5F5.html), [link](http://www.mechano-transformer.com/en/products/01a%5Factuator%5F3.html), [link](http://www.mechano-transformer.com/en/products/01a%5Factuator%5Fmtkk.html) |
| CoreMorrow          | [link](http://www.coremorrow.com/en/pro-13-1.html)                                                                                                                                                                                                |

# Bibliography
<a class="bibtex-entry" id="fleming10_nanop_system_with_force_feedb">Fleming, A., *Nanopositioning system with force feedback for high-performance tracking and vibration control*, IEEE/ASME Transactions on Mechatronics, *15(3)*, 433–447 (2010).  http://dx.doi.org/10.1109/tmech.2009.2028422</a> [↩](#c823f68dd2a72b9667a61b3c046b4731)

<a class="bibtex-entry" id="claeyssen07_amplif_piezoel_actuat">Claeyssen, F., Letty, R. L., Barillot, F., & Sosnicki, O., *Amplified piezoelectric actuators: static \& dynamic applications*, Ferroelectrics, *351(1)*, 3–14 (2007).  http://dx.doi.org/10.1080/00150190701351865</a> [↩](#5decd2b31c4a9842b80c58b56f96590a)

<a class="bibtex-entry" id="lucinskis16_dynam_charac">Lucinskis, R., & Mangeot, C. (2016). *Dynamic characterization of an amplified piezoelectric actuator*. Retrieved from [](). .</a> [↩](#849750850d9986ed326e74bd3c448d03)


## Backlinks {#backlinks}

-   [Actuators]({{< relref "actuators" >}})
